Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(405)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutBox.cpp

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutBox.cpp
diff --git a/third_party/WebKit/Source/core/layout/LayoutBox.cpp b/third_party/WebKit/Source/core/layout/LayoutBox.cpp
index 8d203b08651e60bbcb9308cb84aa526d1e0aae02..5727f7211594c8e3ef43c1a7f10474aa463e724f 100644
--- a/third_party/WebKit/Source/core/layout/LayoutBox.cpp
+++ b/third_party/WebKit/Source/core/layout/LayoutBox.cpp
@@ -2265,7 +2265,7 @@ bool LayoutBox::paintedOutputOfObjectHasNoEffectRegardlessOfSize() const {
return true;
}
-LayoutRect LayoutBox::localOverflowRectForPaintInvalidation() const {
+LayoutRect LayoutBox::localVisualRect() const {
if (style()->visibility() != EVisibility::Visible)
return LayoutRect();
@@ -2403,11 +2403,9 @@ bool LayoutBox::mapToVisualRectInAncestorSpace(
visualRectFlags);
}
-void LayoutBox::inflateVisualRectForFilter(
- LayoutRect& paintInvalidationRect) const {
+void LayoutBox::inflateVisualRectForFilter(LayoutRect& visualRect) const {
if (layer() && layer()->hasFilterInducingProperty())
- paintInvalidationRect =
- layer()->mapLayoutRectForFilter(paintInvalidationRect);
+ visualRect = layer()->mapLayoutRectForFilter(visualRect);
}
void LayoutBox::updateLogicalWidth() {
@@ -5264,8 +5262,7 @@ LayoutObject* LayoutBox::splitAnonymousBoxesAroundChild(
LayoutBox* parentBox = toLayoutBox(boxToSplit->parent());
// We need to invalidate the |parentBox| before inserting the new node
// so that the table paint invalidation logic knows the structure is
// dirty.
// See for example LayoutTableCell:localOverflowRectForPaintInvalidation.
markBoxForRelayoutAfterSplit(parentBox);
parentBox->virtualChildren()->insertChildNode(parentBox, postBox,
boxToSplit->nextSibling());
@@ -5485,10 +5482,10 @@ ShapeOutsideInfo* LayoutBox::shapeOutsideInfo() const {
: nullptr;
}
-void LayoutBox::clearPreviousPaintInvalidationRects() {
- LayoutBoxModelObject::clearPreviousPaintInvalidationRects();
+void LayoutBox::clearPreviousVisualRects() {
+ LayoutBoxModelObject::clearPreviousVisualRects();
if (PaintLayerScrollableArea* scrollableArea = this->getScrollableArea())
- scrollableArea->clearPreviousPaintInvalidationRects();
+ scrollableArea->clearPreviousVisualRects();
}
void LayoutBox::setPercentHeightContainer(LayoutBlock* container) {
« no previous file with comments | « third_party/WebKit/Source/core/layout/LayoutBox.h ('k') | third_party/WebKit/Source/core/layout/LayoutBoxModelObject.cpp » ('j') | no next file with comments »
@@ -5264,8 +5262,7 @@ LayoutObject* LayoutBox::splitAnonymousBoxesAroundChild(
// We need to invalidate the |parentBox| before inserting the new node
// so that the table paint invalidation logic knows the structure is
- // dirty.
- // See for example LayoutTableCell:localOverflowRectForPaintInvalidation.
+ // dirty. See for example LayoutTableCell:localVisualRect().
markBoxForRelayoutAfterSplit(parentBox);
parentBox->virtualChildren()->insertChildNode(parentBox, postBox,

Powered by Google App Engine
This is Rietveld 408576698